Identifying parallel sentences in comparable corpora. Given two sentence-split
monolingual corpora, participant systems are expected to identify pairs of
sentences that are translations of each other.

The BUCC mining task is a shared task on parallel sentence extraction from two
monolingual corpora with a subset of them assumed to be parallel, and that has
been available since 2016. For each language pair, the shared task provides a
monolingual corpus for each language and a gold mapping list containing true
translation pairs. These pairs are the ground truth. The task is to construct a
list of translation pairs from the monolingual corpora. The constructed list is
compared to the ground truth, and evaluated in terms of the F1 measure.
